<template>
  <div class="mod-config">
    <basic-container>
      <el-row>
        <el-col :span="15">
          <ttable
            :table="table"
            @handleSelectionChange="handleSelectionChange"
            @currentChange="handleCurrentChange"
            :uploadInfo="uploadInfo"
            :prelang="prelang"
            :options="options"
            :ajaxFun="ajaxFun"
            ref="exceptionTable"
          >
            <template #toolbar></template>
          </ttable>
        </el-col>
        <el-col :span="9" style="margin-top: 80px">
          <el-upload
            class="upload-demo"
            action="/mes/exception/upload"
            :headers="headers"
            :before-upload="submitUpload"
            :on-preview="handlePreview"
            :on-remove="handleRemove"
            :on-success="uploadSuccess"
            :data="paramData"
            :file-list="fileList"
            list-type="picture"
            :with-credentials="true"
          >
            <el-button size="small" type="primary">点击上传</el-button>
            <div slot="tip" class="el-upload__tip">
              只能上传jpg图片，且不超过2MB
            </div>
          </el-upload>
        </el-col>
      </el-row>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getAddOrUpdateRefreshData"
      ></table-form>
      <detail-form
        v-if="detailFormVisible"
        ref="detailRefForm"
        @refreshDataList="getDetailRefreshData"
      ></detail-form>
    </basic-container>
  </div>
</template>
<style></style>
<script>
import {
  delObj,
  fetchListPage,
  editQualityExceptionProcessStatus
} from '@/api/quality/exception'
import TableForm from './exception-form'
import DetailForm from './detail-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { getStore } from '../../../util/store'
import {
  getExceptionAttachment,
  removeFile
} from '../../../api/quality/exception'
import { remote } from '@/api/admin/dict'
export default {
  data() {
    return {
      fileList: [],
      headers: {
        Authorization: 'Bearer ' + getStore({ name: 'access_token' })
      },
      ajaxFun: fetchListPage,
      addOrUpdateVisible: false,
      detailFormVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      paramData: {
        exceptionId: null
      },
      currentRow: null,
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        isRefresh: true,
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 编号
          {
            minWidth: '30',
            prop: 'code',
            label: '编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',

            render: { fun: this.detailHandle }
          },
          // 工作站
          {
            minWidth: '120',
            prop: 'workstationName',
            label: '工作站',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 产出
          {
            minWidth: '140',
            prop: 'productNo',
            label: '产出',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 异常类型
          {
            minWidth: '120',
            prop: 'exceptionType',
            label: '异常类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 异常描述
          {
            minWidth: '140',
            prop: 'exceptionDescription',
            label: '异常描述',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 处理方案
          {
            minWidth: '140',
            prop: 'handleWay',
            label: '处理方案',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 处理人
          {
            minWidth: '120',
            prop: 'processUserName',
            label: '处理人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 状态
          {
            minWidth: '120',
            prop: 'processStatus',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatExceptionProcessStatusType,
            optList: () => {
              return this.exceptionProcessStatusList
            }
          },
          // 创建时间
          {
            minWidth: '140',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 备注
          {
            minWidth: '140',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle,
            showFun: this.showHandleStatusFun
          },
          {
            text: '修改',
            type: 'text',
            size: 'small',
            fun: this.addOrUpdateHandle,
            showFun: this.showHandleStatusFun
          },
          {
            text: '驳回',
            type: 'text',
            size: 'small',
            fun: this.rejectHandle,
            showFun: this.showAuditStatusFun
          },
          {
            text: '通过',
            type: 'text',
            size: 'small',
            fun: this.passHandle,
            showFun: this.showAuditStatusFun
          },
          {
            text: '处理',
            type: 'text',
            size: 'small',
            fun: this.repaireHandle,
            showFun: this.showHandleStatusFun
          },
          {
            text: '详情',
            type: 'text',
            size: 'small',
            fun: this.detailHandle,
            showFun: this.showDetailStatusFun
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 140,
          minWidth: 140
        }
      },
      exceptionProcessStatusList: []
    }
  },
  components: {
    TableForm,
    ttable,
    DetailForm
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {
    this.getExceptionProcessStatusDict()
  },
  methods: {
    rejectHandle(row) {
      editQualityExceptionProcessStatus({ id: row.id, processStatus: 0 }).then(
        (response) => {
          this.getData().then((res) => {
            this.fileList = []
          })
          this.$message.success('驳回成功')
        }
      )
    },
    passHandle(row) {
      editQualityExceptionProcessStatus({ id: row.id, processStatus: 2 }).then(
        (response) => {
          this.getData().then((res) => {
            this.fileList = []
          })
          this.$message.success('已审核归档')
        }
      )
    },
    repaireHandle(row) {
      this.detailFormVisible = true
      this.$nextTick(() => {
        this.$refs.detailRefForm.init(row == null ? null : row.id, true)
      })
    },
    detailHandle(row) {
      this.detailFormVisible = true
      this.$nextTick(() => {
        this.$refs.detailRefForm.init(row == null ? null : row.id, false)
      })
    },

    getDetailRefreshData() {
      this.getData().then((res) => {
        this.fileList = []
      })
    },

    getAddOrUpdateRefreshData() {
      this.getData().then((res) => {
        this.fileList = []
      })
    },
    // 获取数据列表
    getData() {
      return this.$refs.exceptionTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    handleRemove(file, fileList) {
      if (this.currentRow) {
        removeFile(
          Object.assign({
            fileName: file.fileName
          })
        ).then((response) => {})
      }
    },
    handlePreview(file) {
      window.open(file.url)
    },
    uploadSuccess(response, file, fileList) {
      this.getFileList()
    },
    getFileList() {
      this.fileList = []
      if (this.currentRow && this.currentRow.id) {
        getExceptionAttachment(this.currentRow.id).then((response) => {
          var attachments = response.data.data
          // 渲染附件
          if (attachments != null && attachments.length > 0) {
            var attachment
            var fileEl
            for (var i = 0; i < attachments.length; i++) {
              attachment = attachments[i]
              fileEl = {}
              fileEl.name = attachment.original
              fileEl.url = attachment.url
              fileEl.id = attachment.id
              fileEl.fileName = attachment.fileName
              this.fileList.push(fileEl)
            }
          }
        })
      }
    },
    submitUpload() {
      console.info(this.currentRow && this.currentRow.id)
      if (this.currentRow && this.currentRow.id) {
        this.paramData.exceptionId = this.currentRow.id
      } else {
        this.$message.error('请先选择生产异常记录')
        return false
      }
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除此生产异常反馈编号为：' + row.code + '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    handleCurrentChange(val) {
      this.currentRow = val
      this.uploadSuccess()
    },
    getExceptionProcessStatusDict() {
      this.exceptionProcessStatusList = []
      remote('exception_process_status').then((response) => {
        if (response.data.code === 0) {
          this.exceptionProcessStatusList = response.data.data
        }
      })
    },
    formatExceptionProcessStatusType(row, column, cellValue) {
      this.exceptionProcessStatusList.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    showHandleStatusFun(row) {
      if (row.processStatus == '0') {
        return true
      } else {
        return false
      }
    },
    showAuditStatusFun(row) {
      if (row.processStatus == '1') {
        return true
      } else {
        return false
      }
    },
    showDetailStatusFun(row) {
      if (row.processStatus == '2') {
        return true
      } else {
        return false
      }
    }
  }
}
</script>
